# Topical Guides

```{toctree}
:titlesonly:
powershell_profile
```

Windows users are encouraged to created a [powershell profile][] to assist in
activating their Python Virtual Environment for `artemis_sg`.


## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`

<!-- prettier-ignore-start -->
[powershell profile]:            powershell_profile.md
<!-- prettier-ignore-end -->
